==============
HTMDEC Formats
==============


.. image:: https://img.shields.io/pypi/v/htmdec_formats.svg
        :target: https://pypi.python.org/pypi/htmdec_formats

.. image:: https://img.shields.io/travis/matthewturk/htmdec_formats.svg
        :target: https://travis-ci.com/matthewturk/htmdec_formats

.. image:: https://readthedocs.org/projects/htmdec-formats/badge/?version=latest
        :target: https://htmdec-formats.readthedocs.io/en/latest/?version=latest
        :alt: Documentation Status




Basic format conversion for HTMDEC-relevant data


* Free software: MIT license
* Documentation: https://htmdec-formats.readthedocs.io.


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
